@@ -11,6 +11,10 @@
 --
 -- Wrappers for compiling and running benchmarks quickly and easily.
 -- See 'defaultMain' below for an example.
+--
+-- All of the 'IO'-returning functions in this module initialize the timer
+-- before measuring time (refer to the documentation for 'initializeTime'
+-- for more details).
 
 module Criterion.Main
     (
@@ -44,6 +48,8 @@ module Criterion.Main
     , whnf
     , nfIO
     , whnfIO
+    , nfAppIO
+    , whnfAppIO
     -- * Turning a suite of benchmarks into a program
     , defaultMain
     , defaultMainWith
@@ -69,7 +75,6 @@ import Options.Applicative (execParser)
 import System.Environment (getProgName)
 import System.Exit (ExitCode(..), exitWith)
 import System.FilePath.Glob
-import System.IO.CodePage (withCP65001)
 
 -- | An entry point that can be used as a @main@ function.
 --
@@ -141,7 +146,7 @@ selectBenches matchType benches bsgroup = do
 defaultMainWith :: Config
                 -> [Benchmark]
                 -> IO ()
-defaultMainWith defCfg bs = withCP65001 $ do
+defaultMainWith defCfg bs = do
   wat <- execParser (describe defCfg)
   runMode wat bs
 
@@ -182,7 +187,7 @@ parseError msg = do
 -- number of times.  We are most interested in benchmarking two
 -- things:
 --
--- * 'IO' actions.  Any 'IO' action can be benchmarked directly.
+-- * 'IO' actions.  Most 'IO' actions can be benchmarked directly.
 --
 -- * Pure functions.  GHC optimises aggressively when compiling with
 --   @-O@, so it is easy to write innocent-looking benchmark code that
@@ -192,12 +197,25 @@ parseError msg = do
 
 -- $io
 --
--- Any 'IO' action can be benchmarked easily if its type resembles
--- this:
+-- Most 'IO' actions can be benchmarked easily using one of the following
+-- two functions:
 --
 -- @
--- 'IO' a
+-- 'nfIO'   :: 'NFData' a => 'IO' a -> 'Benchmarkable'
+-- 'whnfIO' ::               'IO' a -> 'Benchmarkable'
 -- @
+--
+-- In certain corner cases, you may find it useful to use the following
+-- variants, which take the input as a separate argument:
+--
+-- @
+-- 'nfAppIO'   :: 'NFData' b => (a -> 'IO' b) -> a -> 'Benchmarkable'
+-- 'whnfAppIO' ::               (a -> 'IO' b) -> a -> 'Benchmarkable'
+-- @
+--
+-- This is useful when the bulk of the work performed by the function is
+-- not bound by IO, but rather by pure computations that may optimize away if
+-- the argument is known statically, as in 'nfIO'/'whnfIO'.
 
 -- $pure
 --
