@@ -18,8 +18,10 @@ module Criterion.Monad.Internal
     ) where
 
 import Control.Monad.Catch (MonadThrow, MonadCatch, MonadMask)
+import qualified Control.Monad.Fail as Fail (MonadFail(..))
 import Control.Monad.Reader (MonadReader(..), ReaderT)
 import Control.Monad.Trans (MonadIO)
+import Control.Monad.Trans.Instances ()
 import Criterion.Types (Config)
 import Data.IORef (IORef)
 import Prelude ()
@@ -34,7 +36,8 @@ data Crit = Crit {
 -- | The monad in which most criterion code executes.
 newtype Criterion a = Criterion {
       runCriterion :: ReaderT Crit IO a
-    } deriving (Functor, Applicative, Monad, MonadIO, MonadThrow, MonadCatch, MonadMask)
+    } deriving ( Functor, Applicative, Monad, Fail.MonadFail, MonadIO
+               , MonadThrow, MonadCatch, MonadMask )
 
 instance MonadReader Config Criterion where
     ask     = config `fmap` Criterion ask
